@@ -5,6 +5,7 @@ import numpy as np
 import datetime
 from pathlib import Path
 from openpyxl import load_workbook
+import chardet
 
 def settings_importer(file_path: Path, sheet_index:int)->list:
     '''
@@ -178,4 +179,15 @@ def ageing_creator(df:pd.DataFrame, col:str, to_date:datetime.date=datetime.date
     binned = pd.cut(diff, bins=bins_converted, include_lowest=True, right=True, labels=bins_labels)
     del diff
 
-    return binned
\ No newline at end of file
+    return binned
+
+def csv_encoding(file_path:Path)->list:
+    '''
+    Takes path to a csv file and determines the csv encoding. Returns [encoding, confidence, language]
+    '''
+    if file_path.is_file and file_path.suffix == '.csv':
+        with open(file_path, 'rb') as rawdata:
+            result = chardet.detect(rawdata.read(10000))
+        return result
+    else:
+        return [None, 'Path is not a file or a csv']
\ No newline at end of file
